Marker trait. Implement only for types that
Are not part of PaxValue, but need to be stored
inside a PaxAny
Trait that marks a type as being representable as a PaxAny, and provides the
implementation for going to/from that type. For all builtins this means
going to/from a pax value. For others to a Box. This is automatically
Implemented for PaxValue types through the macro impl_to_from_pax_value!,
and for other types by implementing the marker trait ImplToFromPaxAny.
This trait is implemented by all types that
has a bultin equivalent representation (see to_from_impls module)
This is NOT responsible for coercing between types, but returns
an err in all cases where the underlying type is not exactly what is expected