pub trait ToPaxValue {
// Required method
fn to_pax_value(self) -> PaxValue;
}Expand description
This trait is implemented by all types that has a builtin equivalent representation (see to_from_impls module) This is NOT responsible for coercing between types, but returns an err in all cases where the underlying type is not exactly what is expected
Required Methods
fn to_pax_value(self) -> PaxValue
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".