Store

Trait Store 

pub trait Store: 'static { }
Marker trait that needs to be implemented for a struct for insertion and deletion in a store NOTE: Stored objects need to be UNIQUE for any given stack. Do not insert values with types that could potentially be used in another use case, instead create a local new type (newtype pattern) only used for a single purpose

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors